@@ -1,9 +1,6 @@
-#!/usr/bin/env seed
-// Returns: 0
-// STDIN:
-// STDOUT:\{"Hello":"World"\}
-// STDERR:
+#!../../../src/seed
 
+testsuite = imports.testsuite
 Gtk = imports.gi.Gtk;
 JSON = imports.JSON;
 
@@ -11,9 +8,11 @@ Gtk.init(Seed.argv);
 
 function userdata_test(widget, user_data)
 {
-    print(JSON.stringify(user_data));
+    testsuite.assert(user_data.Hello == "World")
 }
 
 w = new Gtk.Window();
 w.signal.map.connect(userdata_test, {Hello: "World"});
 w.show();
+
+testsuite.checkAsserts(1)
